## 2D example

You can run this example by typing:

```
ttcr2d -v -p modele2d.par
```

The output files obtained on my machine are in the subdirectory out.

### Python wrapper

An example showing how to do raytracing on a 2D triangular mesh is presented in
example_cmesh2d.ipynp.
